@@ -13,7 +13,7 @@
 use v5.14;
 use warnings;
 
-package Sys::Async::Virt::URI v10.3.9;
+package Protocol::Sys::Virt::URI v10.3.10;
 
 use parent qw(Exporter);
 
@@ -76,7 +76,7 @@ Protocol::Sys::Virt::URI - Helper routines for parsing LibVirt URIs
 
 =head1 VERSION
 
-v10.3.9
+v10.3.10
 
 =head1 SYNOPSIS
 
